==> adminer_3.3.3.orig.tar.gz: adminer-3.3.3/adminer/lang/ja.inc.php <==
<?php
$translations = array(
	'Login' => 'ログイン',
	'Logout successful.' => 'ログアウト',
	'Invalid credentials.' => '不正なログイン',
	'Server' => 'サーバ',
	'Username' => 'ユーザ名',
	'Password' => 'パスワード',
	'Select database' => 'データベースを選択してください',
	'Invalid database.' => '不正なデータベース',
	'Create new database' => '新規にデータベースを作成',
	'Table has been dropped.' => 'テーブルを削除しました',
	'Table has been altered.' => 'テーブルを変更しました',
	'Table has been created.' => 'テーブルを作成しました',
	'Alter table' => 'テーブルの変更',
	'Create table' => 'テーブルを作成',
	'Table name' => 'テーブル名',
	'engine' => 'エンジン',
	'collation' => '照合順序',
	'Column name' => '列名',
	'Type' => '型',
	'Length' => '長さ',
	'Auto Increment' => '連番',
	'Options' => '設定',
	'Save' => '保存',
	'Drop' => '削除',
	'Database has been dropped.' => 'データベースを削除しました',
	'Database has been created.' => 'データベースを作成しました',
	'Database has been renamed.' => 'データベースの名前を変えました',
	'Database has been altered.' => 'データベースを変更しました',
	'Alter database' => 'データベースを変更',
	'Create database' => 'データベースを作成',
	'SQL command' => 'SQLコマンド',
	'Dump' => 'ダンプ',
	'Logout' => 'ログアウト',
	'database' => 'データベース',
	'Use' => '使用',
	'No tables.' => 'テーブルがありません。',
	'select' => '選択',
	'Create new table' => 'テーブルを作成',
	'Item has been deleted.' => '項目を削除しました',
	'Item has been updated.' => '項目を更新しました',
	'Edit' => '編集',
	'Insert' => '挿入',
	'Save and insert next' => '保存／追加',
	'Delete' => '削除',
	'Database' => 'データベース',
	'Routines' => 'ルーチン',
	'Indexes have been altered.' => '索引を変更しました',
	'Indexes' => '索引',
	'Alter indexes' => '索引の変更',
	'Add next' => '追加',
	'Language' => '言語',
	'Select' => '選択',
	'New item' => '項目の作成',
	'Search' => '検索',
	'Sort' => 'ソート',
	'descending' => '降順',
	'Limit' => '制約',
	'No rows.' => '行がありません',
	'Action' => '動作',
	'edit' => '編集',
	'Page' => 'ページ',
	'Query executed OK, %d row(s) affected.' => 'クエリーを実行しました。%d 行を変更しました',
	'Error in query' => 'クエリーのエラー',
	'Execute' => '実行',
	'Table' => 'テーブル',
	'Foreign keys' => '外部キー',
	'Triggers' => 'トリガー',
	'View' => 'ビュー',
	'Unable to select the table' => 'テーブルを選択できません',
	'Invalid CSRF token. Send the form again.' => '不正なCSRFトークン。再送信してください',
	'Comment' => 'コメント',
	'Default values' => '規定値',
	'%d byte(s)' => '%d バイト',
	'No commands to execute.' => '実行するコマンドがありません',
	'Unable to upload a file.' => 'ファイルをアップロードできません',
	'File upload' => 'ファイルをアップロード',
	'File uploads are disabled.' => 'ファイルのアップロードが無効です',
	'Routine has been called, %d row(s) affected.' => 'ルーチンを呼びました。%d 行を変更しました',
	'Call' => '呼出し',
	'No extension' => '拡張機能がありません',
	'None of the supported PHP extensions (%s) are available.' => 'PHPの拡張機能（%s）がセットアップされていません',
	'Session support must be enabled.' => 'セッションを有効にしてください',
	'Session expired, please login again.' => 'セッションの期限切れ。ログインし直してください',
	'Text length' => '文字列の長さ',
	'Foreign key has been dropped.' => '外部キーを削除しました',
	'Foreign key has been altered.' => '外部キーを変更しました',
	'Foreign key has been created.' => '外部キーを作成しました',
	'Foreign key' => '外キー',
	'Target table' => 'テーブル',
	'Change' => '変更',
	'Source' => 'ソース',
	'Target' => 'ターゲット',
	'Add column' => '列を追加',
	'Alter' => '変更',
	'Add foreign key' => '外部キーを追加',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => '索引の型',
	'Column (length)' => '列（長さ）',
	'View has been dropped.' => 'ビューを削除しました',
	'View has been altered.' => 'ビューを変更しました',
	'View has been created.' => 'ビューを作成しました',
	'Alter view' => 'ビューを変更',
	'Create view' => 'ビューを作成',
	'Name' => '名称',
	'Process list' => 'プロセス一覧',
	'%d process(es) have been killed.' => '%d プロセスを強制終了しました',
	'Kill' => '強制終了',
	'Parameter name' => '参数名',
	'Database schema' => '構造',
	'Create procedure' => 'プロシージャの作成',
	'Create function' => '関数の作成',
	'Routine has been dropped.' => 'ルーチンを作成',
	'Routine has been altered.' => 'ルーチンを変更',
	'Routine has been created.' => 'ルーチンを作成',
	'Alter function' => '関数の変更',
	'Alter procedure' => 'プロシージャの変更',
	'Return type' => '戻り値の型',
	'Add trigger' => 'トリガーの追加',
	'Trigger has been dropped.' => 'トリガーを削除しました',
	'Trigger has been altered.' => 'トリガーを変更しました',
	'Trigger has been created.' => 'トリガーを追加しました',
	'Alter trigger' => 'トリガーの変更',
	'Create trigger' => 'トリガーの作成',
	'Time' => '時間',
	'Event' => 'イベント',
	'%s version: %s through PHP extension %s' => '%sバージョン：%s、 PHP拡張機能 %s',
	'%d row(s)' => '%d 行',
	'Remove' => '除外',
	'Are you sure?' => '実行しますか？',
	'Privileges' => '権限',
	'Create user' => 'ユーザを作成',
	'User has been dropped.' => 'ユーザを削除',
	'User has been altered.' => 'ユーザを変更',
	'User has been created.' => 'ユーザを作成',
	'Hashed' => 'Hashed',
	'Column' => '列',
	'Routine' => 'ルーチン',
	'Grant' => '権限の付与',
	'Revoke' => '権限の取消し',
	'Logged as: %s' => 'ログ：%s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POSTデータが大きすぎます。データサイズを小さくするか %s 設定を大きくしてください',
	'Move up' => '上',
	'Move down' => '下',
	'Export' => 'エクスポート',
	'Tables' => 'テーブル',
	'Data' => 'データ',
	'Output' => '出力',
	'open' => '開く',
	'save' => '保存',
	'Format' => '形式',
	'Functions' => '関数',
	'Aggregation' => '集合',
	'Event has been dropped.' => '削除しました',
	'Event has been altered.' => '変更しました',
	'Event has been created.' => '作成しました',
	'Alter event' => '変更',
	'Create event' => '作成',
	'Start' => '開始',
	'End' => '終了',
	'Every' => '毎回',
	'Status' => '状態',
	'On completion preserve' => '完成後に保存',
	'Events' => 'イベント',
	'Schedule' => 'スケジュール',
	'At given time' => '指定時刻',
	'Tables have been truncated.' => 'テーブルをtruncateしました',
	'Tables have been moved.' => 'テーブルを移動しました',
	'Tables and views' => 'テーブルとビュー',
	'Engine' => 'エンジン',
	'Collation' => '照合順序',
	'Data Length' => 'データ長',
	'Index Length' => '索引長',
	'Data Free' => '空き',
	'Rows' => '行数',
	',' => ',',
	'Analyze' => '分析',
	'Optimize' => '最適化',
	'Check' => 'チェック',
	'Repair' => '修復',
	'Truncate' => 'Truncate',
	'Move to other database' => '別のデータベースへ移動',
	'Move' => '移動',
	'Save and continue edit' => '保存して継続',
	'original' => '元',
	'%d item(s) have been affected.' => '%d を更新しました',
	'whole result' => '全結果',
	'Tables have been dropped.' => 'テーブルを削除しました',
	'Clone' => 'クローン',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => '定義可能な最大フィールド数を越えました。%s と %s を増やしてください。',
	'Partition by' => 'パーティション',
	'Partitions' => 'パーティション',
	'Partition name' => 'パーティション名',
	'Values' => '値',
	'%d row(s) have been imported.' => '%d 行をインポートしました',
	'Show structure' => '構造',
	'anywhere' => '任意',
	'Import' => 'インポート',
	'Stop on error' => 'エラーの場合は停止',
	'Select data' => 'データ',
	'%.3f s' => '%.3f 秒',
	'$1-$3-$5' => '$1.$3.$5',
	'[yyyy]-mm-dd' => '[yyyy].mm.dd',
	'History' => '履歴',
	'Variables' => '変数',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'ソースとターゲットの列は同じデータ型でなければなりません。ターゲット列に索引があり、データが存在しなければなりません。',
	'Relations' => '関係',
	'Run file' => 'ファイルを実行',
	'Clear' => '消去',
	'Maximum allowed file size is %sB.' => '最大ファイルサイズ %sB',
	'Numbers' => '数字',
	'Date and time' => '日時',
	'Strings' => '文字列',
	'Binary' => 'バイナリ',
	'Lists' => 'リスト',
	'Editor' => 'エディタ',
	'E-mail' => 'メール',
	'From' => '差出人',
	'Subject' => '題名',
	'Send' => '送信',
	'%d e-mail(s) have been sent.' => '%d メールを送信しました',
	'Webserver file %s' => 'Webサーバファイル %s',
	'File does not exist.' => 'ファイルは存在しません',
	'%d in total' => '合計 %d',
	'Permanent login' => '永続的にログイン',
	'Databases have been dropped.' => 'データベースを削除しました',
	'Search data in tables' => 'データを検索する',
	'schema' => 'スキーマ',
	'Schema' => 'スキーマ',
	'Alter schema' => 'スキーマ変更',
	'Create schema' => 'スキーマ追加',
	'Schema has been dropped.' => 'スキーマを削除しました',
	'Schema has been created.' => 'スキーマを追加しました',
	'Schema has been altered.' => 'スキーマを変更しました',
	'Sequences' => 'シーケンス',
	'Create sequence' => 'シーケンス作成',
	'Alter sequence' => 'シーケンス変更',
	'Sequence has been dropped.' => 'シーケンスを削除しました',
	'Sequence has been created.' => 'シーケンスを追加しました',
	'Sequence has been altered.' => 'シーケンスを変更しました',
	'User types' => 'ユーザー定義型',
	'Create type' => 'ユーザー定義型作成',
	'Alter type' => 'ユーザー定義型変更',
	'Type has been dropped.' => 'ユーザー定義型を削除しました',
	'Type has been created.' => 'ユーザー定義型を追加しました',
	'Double click on a value to modify it.' => 'ダブルクリックして編集',
	'Use edit link to modify this value.' => 'リンクを編集する',
	'last' => '最終',
	'From server' => 'サーバーから実行',
	'System' => 'データベース種類',
	'empty' => '空',
	'Network' => 'ネットワーク型',
	'Geometry' => 'ジオメトリ型',
	'File exists.' => 'ファイルが既に存在します',
	'Attachments' => '添付ファイル',
	'Item%s has been inserted.' => '%s項目を挿入しました',
	'now' => '現在の日時',
	'%d query(s) executed OK.' => '%d クエリーを実行しました',
	'Show only errors' => 'エラーのみ表示',
	'Last page' => '最後のページ',
	'Refresh' => 'リフレッシュ',
	'Invalid schema.' => '無効なスキーマ',
	'Please use one of the extensions %s.' => 'いずれかの拡張機能を使ってください %s',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'テーブルをコピーしました',
	'Copy' => 'コピー',
	'Permanent link' => 'パーマネントリンク',
	'Edit all' => 'すべて編集',
	'Resend POST data?' => '再送信しますか？',
	'HH:MM:SS' => '時:分:秒',
);

==> adminer_4.2.1.orig.tar.gz: adminer-4.2.1/adminer/lang/ja.inc.php <==
<?php
$translations = array(
	'Login' => 'ログイン',
	'Logout successful.' => 'ログアウト',
	'Invalid credentials.' => '不正なログイン',
	'Server' => 'サーバ',
	'Username' => 'ユーザ名',
	'Password' => 'パスワード',
	'Select database' => 'データベースを選択してください',
	'Invalid database.' => '不正なデータベース',
	'Create new database' => '新規にデータベースを作成',
	'Table has been dropped.' => 'テーブルを削除しました',
	'Table has been altered.' => 'テーブルを変更しました',
	'Table has been created.' => 'テーブルを作成しました',
	'Alter table' => 'テーブルの変更',
	'Create table' => 'テーブルを作成',
	'Table name' => 'テーブル名',
	'engine' => 'エンジン',
	'collation' => '照合順序',
	'Column name' => '列名',
	'Type' => '型',
	'Length' => '長さ',
	'Auto Increment' => '連番',
	'Options' => '設定',
	'Save' => '保存',
	'Drop' => '削除',
	'Database has been dropped.' => 'データベースを削除しました',
	'Database has been created.' => 'データベースを作成しました',
	'Database has been renamed.' => 'データベースの名前を変えました',
	'Database has been altered.' => 'データベースを変更しました',
	'Alter database' => 'データベースを変更',
	'Create database' => 'データベースを作成',
	'SQL command' => 'SQLコマンド',
	'Logout' => 'ログアウト',
	'database' => 'データベース',
	'Use' => '使用',
	'No tables.' => 'テーブルがありません。',
	'select' => '選択',
	'Item has been deleted.' => '項目を削除しました',
	'Item has been updated.' => '項目を更新しました',
	'Edit' => '編集',
	'Insert' => '挿入',
	'Save and insert next' => '保存／追加',
	'Delete' => '削除',
	'Database' => 'データベース',
	'Routines' => 'ルーチン',
	'Indexes have been altered.' => '索引を変更しました',
	'Indexes' => '索引',
	'Alter indexes' => '索引の変更',
	'Add next' => '追加',
	'Language' => '言語',
	'Select' => '選択',
	'New item' => '項目の作成',
	'Search' => '検索',
	'Sort' => 'ソート',
	'descending' => '降順',
	'Limit' => '制約',
	'No rows.' => '行がありません',
	'Action' => '動作',
	'edit' => '編集',
	'Page' => 'ページ',
	'Query executed OK, %d row(s) affected.' => 'クエリーを実行しました。%d 行を変更しました',
	'Error in query' => 'クエリーのエラー',
	'Execute' => '実行',
	'Table' => 'テーブル',
	'Foreign keys' => '外部キー',
	'Triggers' => 'トリガー',
	'View' => 'ビュー',
	'Unable to select the table' => 'テーブルを選択できません',
	'Invalid CSRF token. Send the form again.' => '不正なCSRFトークン。再送信してください',
	'Comment' => 'コメント',
	'Default values' => '規定値',
	'%d byte(s)' => '%d バイト',
	'No commands to execute.' => '実行するコマンドがありません',
	'Unable to upload a file.' => 'ファイルをアップロードできません',
	'File upload' => 'ファイルをアップロード',
	'File uploads are disabled.' => 'ファイルのアップロードが無効です',
	'Routine has been called, %d row(s) affected.' => 'ルーチンを呼びました。%d 行を変更しました',
	'Call' => '呼出し',
	'No extension' => '拡張機能がありません',
	'None of the supported PHP extensions (%s) are available.' => 'PHPの拡張機能（%s）がセットアップされていません',
	'Session support must be enabled.' => 'セッションを有効にしてください',
	'Session expired, please login again.' => 'セッションの期限切れ。ログインし直してください',
	'Text length' => '文字列の長さ',
	'Foreign key has been dropped.' => '外部キーを削除しました',
	'Foreign key has been altered.' => '外部キーを変更しました',
	'Foreign key has been created.' => '外部キーを作成しました',
	'Foreign key' => '外キー',
	'Target table' => 'テーブル',
	'Change' => '変更',
	'Source' => 'ソース',
	'Target' => 'ターゲット',
	'Add column' => '列を追加',
	'Alter' => '変更',
	'Add foreign key' => '外部キーを追加',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => '索引の型',
	'Column (length)' => '列（長さ）',
	'View has been dropped.' => 'ビューを削除しました',
	'View has been altered.' => 'ビューを変更しました',
	'View has been created.' => 'ビューを作成しました',
	'Alter view' => 'ビューを変更',
	'Create view' => 'ビューを作成',
	'Name' => '名称',
	'Process list' => 'プロセス一覧',
	'%d process(es) have been killed.' => '%d プロセスを強制終了しました',
	'Kill' => '強制終了',
	'Parameter name' => '参数名',
	'Database schema' => '構造',
	'Create procedure' => 'プロシージャの作成',
	'Create function' => '関数の作成',
	'Routine has been dropped.' => 'ルーチンを作成',
	'Routine has been altered.' => 'ルーチンを変更',
	'Routine has been created.' => 'ルーチンを作成',
	'Alter function' => '関数の変更',
	'Alter procedure' => 'プロシージャの変更',
	'Return type' => '戻り値の型',
	'Add trigger' => 'トリガーの追加',
	'Trigger has been dropped.' => 'トリガーを削除しました',
	'Trigger has been altered.' => 'トリガーを変更しました',
	'Trigger has been created.' => 'トリガーを追加しました',
	'Alter trigger' => 'トリガーの変更',
	'Create trigger' => 'トリガーの作成',
	'Time' => '時間',
	'Event' => 'イベント',
	'%s version: %s through PHP extension %s' => '%sバージョン：%s、 PHP拡張機能 %s',
	'%d row(s)' => '%d 行',
	'Remove' => '除外',
	'Are you sure?' => '実行しますか？',
	'Privileges' => '権限',
	'Create user' => 'ユーザを作成',
	'User has been dropped.' => 'ユーザを削除',
	'User has been altered.' => 'ユーザを変更',
	'User has been created.' => 'ユーザを作成',
	'Hashed' => 'Hashed',
	'Column' => '列',
	'Routine' => 'ルーチン',
	'Grant' => '権限の付与',
	'Revoke' => '権限の取消し',
	'Logged as: %s' => 'ログ：%s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POSTデータが大きすぎます。データサイズを小さくするか %s 設定を大きくしてください',
	'Move up' => '上',
	'Move down' => '下',
	'Export' => 'エクスポート',
	'Tables' => 'テーブル',
	'Data' => 'データ',
	'Output' => '出力',
	'open' => '開く',
	'save' => '保存',
	'Format' => '形式',
	'Functions' => '関数',
	'Aggregation' => '集合',
	'Event has been dropped.' => '削除しました',
	'Event has been altered.' => '変更しました',
	'Event has been created.' => '作成しました',
	'Alter event' => '変更',
	'Create event' => '作成',
	'Start' => '開始',
	'End' => '終了',
	'Every' => '毎回',
	'Status' => '状態',
	'On completion preserve' => '完成後に保存',
	'Events' => 'イベント',
	'Schedule' => 'スケジュール',
	'At given time' => '指定時刻',
	'Tables have been truncated.' => 'テーブルをtruncateしました',
	'Tables have been moved.' => 'テーブルを移動しました',
	'Tables and views' => 'テーブルとビュー',
	'Engine' => 'エンジン',
	'Collation' => '照合順序',
	'Data Length' => 'データ長',
	'Index Length' => '索引長',
	'Data Free' => '空き',
	'Rows' => '行数',
	',' => ',',
	'0123456789' => '0123456789',
	'Analyze' => '分析',
	'Optimize' => '最適化',
	'Check' => 'チェック',
	'Repair' => '修復',
	'Truncate' => 'Truncate',
	'Move to other database' => '別のデータベースへ移動',
	'Move' => '移動',
	'Save and continue edit' => '保存して継続',
	'original' => '元',
	'%d item(s) have been affected.' => '%d を更新しました',
	'whole result' => '全結果',
	'Tables have been dropped.' => 'テーブルを削除しました',
	'Clone' => 'クローン',
	'Maximum number of allowed fields exceeded. Please increase %s.' => '定義可能な最大フィールド数を越えました。%s を増やしてください。',
	'Partition by' => 'パーティション',
	'Partitions' => 'パーティション',
	'Partition name' => 'パーティション名',
	'Values' => '値',
	'%d row(s) have been imported.' => '%d 行をインポートしました',
	'Show structure' => '構造',
	'anywhere' => '任意',
	'Import' => 'インポート',
	'Stop on error' => 'エラーの場合は停止',
	'Select data' => 'データ',
	'%.3f s' => '%.3f 秒',
	'$1-$3-$5' => '$1.$3.$5',
	'[yyyy]-mm-dd' => '[yyyy].mm.dd',
	'History' => '履歴',
	'Variables' => '変数',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'ソースとターゲットの列は同じデータ型でなければなりません。ターゲット列に索引があり、データが存在しなければなりません。',
	'Relations' => '関係',
	'Run file' => 'ファイルを実行',
	'Clear' => '消去',
	'Maximum allowed file size is %sB.' => '最大ファイルサイズ %sB',
	'Numbers' => '数字',
	'Date and time' => '日時',
	'Strings' => '文字列',
	'Binary' => 'バイナリ',
	'Lists' => 'リスト',
	'Editor' => 'エディタ',
	'E-mail' => 'メール',
	'From' => '差出人',
	'Subject' => '題名',
	'Send' => '送信',
	'%d e-mail(s) have been sent.' => '%d メールを送信しました',
	'Webserver file %s' => 'Webサーバファイル %s',
	'File does not exist.' => 'ファイルは存在しません',
	'%d in total' => '合計 %d',
	'Permanent login' => '永続的にログイン',
	'Databases have been dropped.' => 'データベースを削除しました',
	'Search data in tables' => 'データを検索する',
	'Schema' => 'スキーマ',
	'Alter schema' => 'スキーマ変更',
	'Create schema' => 'スキーマ追加',
	'Schema has been dropped.' => 'スキーマを削除しました',
	'Schema has been created.' => 'スキーマを追加しました',
	'Schema has been altered.' => 'スキーマを変更しました',
	'Sequences' => 'シーケンス',
	'Create sequence' => 'シーケンス作成',
	'Alter sequence' => 'シーケンス変更',
	'Sequence has been dropped.' => 'シーケンスを削除しました',
	'Sequence has been created.' => 'シーケンスを追加しました',
	'Sequence has been altered.' => 'シーケンスを変更しました',
	'User types' => 'ユーザー定義型',
	'Create type' => 'ユーザー定義型作成',
	'Alter type' => 'ユーザー定義型変更',
	'Type has been dropped.' => 'ユーザー定義型を削除しました',
	'Type has been created.' => 'ユーザー定義型を追加しました',
	'Use edit link to modify this value.' => 'リンクを編集する',
	'last' => '最終',
	'From server' => 'サーバーから実行',
	'System' => 'データベース種類',
	'empty' => '空',
	'Network' => 'ネットワーク型',
	'Geometry' => 'ジオメトリ型',
	'File exists.' => 'ファイルが既に存在します',
	'Attachments' => '添付ファイル',
	'Item%s has been inserted.' => '%s項目を挿入しました',
	'now' => '現在の日時',
	'%d query(s) executed OK.' => '%d クエリーを実行しました',
	'Show only errors' => 'エラーのみ表示',
	'Refresh' => 'リフレッシュ',
	'Invalid schema.' => '無効なスキーマ',
	'Please use one of the extensions %s.' => 'いずれかの拡張機能を使ってください %s',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'テーブルをコピーしました',
	'Copy' => 'コピー',
	'Permanent link' => 'パーマネントリンク',
	'Edit all' => 'すべて編集',
	'HH:MM:SS' => '時:分:秒',
);
